Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(684)

Unified Diff: gclient_utils.py

Issue 7858001: Update docstrings w.r.t. subprocess2. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/depot_tools
Patch Set: Created 9 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | subprocess2.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gclient_utils.py
diff --git a/gclient_utils.py b/gclient_utils.py
index 0bae71276323b29ada68d342e6c9c9c6d0be156b..350de22e812b53988203d316905c2c6ddecbfa0f 100644
--- a/gclient_utils.py
+++ b/gclient_utils.py
@@ -320,10 +320,10 @@ def CheckCallAndFilter(args, stdout=None, filter_fn=None,
**kwargs):
"""Runs a command and calls back a filter function if needed.
- Accepts all subprocess.Popen() parameters plus:
+ Accepts all subprocess2.Popen() parameters plus:
print_stdout: If True, the command's stdout is forwarded to stdout.
filter_fn: A function taking a single string argument called with each line
of the subprocess's output. Each line has the trailing newline
character trimmed.
stdout: Can be any bufferable output.
@@ -337,7 +337,7 @@ def CheckCallAndFilter(args, stdout=None, filter_fn=None,
args, bufsize=0, stdout=subprocess2.PIPE, stderr=subprocess2.STDOUT,
**kwargs)
# Do a flush of stdout before we begin reading from the subprocess's stdout
stdout.flush()
# Also, we need to forward stdout to prevent weird re-ordering of output.
« no previous file with comments | « no previous file | subprocess2.py » ('j') | no next file with comments »
@@ -320,10 +320,10 @@ def CheckCallAndFilter(args, stdout=None, filter_fn=None,
print_stdout: If True, the command's stdout is forwarded to stdout.
filter_fn: A function taking a single string argument called with each line
- of the subprocess's output. Each line has the trailing newline
+ of the subprocess2's output. Each line has the trailing newline
character trimmed.
stdout: Can be any bufferable output.
@@ -337,7 +337,7 @@ def CheckCallAndFilter(args, stdout=None, filter_fn=None,
args, bufsize=0, stdout=subprocess2.PIPE, stderr=subprocess2.STDOUT,
**kwargs)
- # Do a flush of stdout before we begin reading from the subprocess's stdout
+ # Do a flush of stdout before we begin reading from the subprocess2's stdout
stdout.flush()
# Also, we need to forward stdout to prevent weird re-ordering of output.

Powered by Google App Engine
This is Rietveld 408576698